from .css import CssFormat
from .cocos2d import Cocos2dFormat
from .img import ImageFormat
from .html import HtmlFormat
from .jsonformat import JSONFormat
from .caat import CAATFormat
from .less import LessFormat
from .scss import ScssFormat


formats = {'css': CssFormat,
           'cocos2d': Cocos2dFormat,
           'img': ImageFormat,
           'html': HtmlFormat,
           'json': JSONFormat,
           'caat': CAATFormat,
           'less': LessFormat,
           'scss': ScssFormat}



import os

from css import CssFormat


class ScssFormat(CssFormat):

    extension = 'scss'

    @classmethod
    def populate_argument_parser(cls, parser):
        group = parser.add_argument_group("SCSS format options")

        group.add_argument("--scss",
                           dest="scss_dir",
                           nargs='?',
                           const=True,
                           default=os.environ.get('GLUE_SCSS', False),
                           metavar='DIR',
                           help="Generate SCSS files and optionally where")

        group.add_argument("--scss-template",
                           dest="scss_template",
                           default=os.environ.get('GLUE_SCSS_TEMPLATE', None),
                           metavar='DIR',
                           help="Template to use to generate the SCSS output.")



import os

from css import CssFormat


class LessFormat(CssFormat):

    extension = 'less'
    template = u"""
        /* glue: {{ version }} hash: {{ hash }} */
        {% for image in images %}.{{ image.label }}{{ image.pseudo }}{%- if not image.last %}, {%- endif %}{%- endfor %}{
            background-image:url('{{ sprite_path }}');
            background-repeat:no-repeat;
            -webkit-background-size: {{ width }}px {{ height }}px;
            -moz-background-size: {{ width }}px {{ height }}px;
            background-size: {{ width }}px {{ height }}px;
            {% for r, ratio in ratios.items() %}
            @media screen and (-webkit-min-device-pixel-ratio: {{ ratio.ratio }}), screen and (min--moz-device-pixel-ratio: {{ ratio.ratio }}),screen and (-o-min-device-pixel-ratio: {{ ratio.fraction }}),screen and (min-device-pixel-ratio: {{ ratio.ratio }}),screen and (min-resolution: {{ ratio.ratio }}dppx){
                background-image:url('{{ ratio.sprite_path }}');
            }
            {% endfor %}
        }
        {% for image in images %}
        .{{ image.label }}{{ image.pseudo }}{
            background-position:{{ image.x ~ ('px' if image.x) }} {{ image.y ~ ('px' if image.y) }};
            width:{{ image.width }}px;
            height:{{ image.height }}px;
        }
        {% endfor %}
        """

    @classmethod
    def populate_argument_parser(cls, parser):
        group = parser.add_argument_group("CSS format options")

        group.add_argument("--less",
                           dest="less_dir",
                           nargs='?',
                           const=True,
                           default=os.environ.get('GLUE_LESS', False),
                           metavar='DIR',
                           help="Generate LESS files and optionally where")

        group.add_argument("--less-template",
                           dest="less_template",
                           default=os.environ.get('GLUE_LESS_TEMPLATE', None),
                           metavar='DIR',
                           help="Template to use to generate the LESS output.")



import sys

from setuptools import setup, find_packages

install_requires=[
    'Pillow>=2.2.2',
    'Jinja2>=2.7,<2.10',
]

tests_require=[
    'cssutils>=0.9.10,<1.0',
]

# as of Python >= 2.7 argparse module is maintained within Python.
if sys.version_info < (2, 7):
    install_requires.append('argparse>=1.1')
    install_requires.append('ordereddict>=1.1')


# as of Python >= 3.3 unittest.mock module is maintained within Python.
if sys.version_info < (3, 3):
    tests_require.append('mock>=1.0')


setup(
    name='glue',
    version='0.13',
    url='http://github.com/jorgebastida/glue',
    license='BSD',
    author='Jorge Bastida',
    author_email='me@jorgebastida.com',
    description='Glue is a simple command line tool to generate sprites.',
    long_description=('Glue is a simple command line tool to generate '
                      'sprites using any kind of source images like '
                      'PNG, JPEG or GIF. Glue will generate a unique PNG '
                      'file containing every source image and a map file '
                      'including the necessary information to use it.'),
    keywords = "glue sprites css cocos2d",
    packages = find_packages(),
    platforms='any',
    install_requires=install_requires,
    tests_require=tests_require,
    test_suite='tests',
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Topic :: Utilities'
    ],
    entry_points = {
        'console_scripts': [
            'glue = glue.bin:main',
        ]
    },
    zip_safe = False,
    use_2to3=True
)
